@@ -6,18 +6,17 @@
 /* Define to 1 if you have the `gmtime_r' function. */
 /* #undef HAVE_GMTIME_R */
 
-/* Define if you have an STL implementation that supports useful string
-   specialization. */
-#define HAVE_GOOD_STL 1
-
 /* Define to 1 if you have the <inttypes.h> header file. */
 /* #undef HAVE_INTTYPES_H */
 
 /* Define if log4shib library is used. */
-#define HAVE_LOG4SHIB 1
+#define OPENSAML_LOG4SHIB 1
 
 /* Define if log4cpp library is used. */
-/* #undef HAVE_LOG4CPP */
+/* #undef OPENSAML_LOG4CPP */
+
+/* Define if Xerces-C library was found */
+#define HAVE_LIBXERCESC 1
 
 /* Define to 1 if you have the <memory.h> header file. */
 #define HAVE_MEMORY_H 1
@@ -25,9 +24,6 @@
 /* define if the compiler implements namespaces */
 #define HAVE_NAMESPACES 1
 
-/* Define if you have POSIX threads libraries and header files. */
-/* #undef HAVE_PTHREAD */
-
 /* Define to 1 if you have the <stdint.h> header file. */
 /* #undef HAVE_STDINT_H */
 
@@ -40,9 +36,6 @@
 /* Define to 1 if you have the `strdup' function. */
 #define HAVE_STRDUP 1
 
-/* Define to 1 if you have the `strftime' function. */
-/* #undef HAVE_STRFTIME */
-
 /* Define to 1 if you have the <strings.h> header file. */
 /* #undef HAVE_STRINGS_H */
 
@@ -62,7 +55,7 @@
 /* #undef HAVE_UNISTD_H */
 
 /* Name of package */
-#define PACKAGE "saml"
+#define PACKAGE "opensaml"
 
 /* Define to the address where bug reports for this package should be sent. */
 #define PACKAGE_BUGREPORT "mace-opensaml-users@internet2.edu"
@@ -71,13 +64,13 @@
 #define PACKAGE_NAME "opensaml"
 
 /* Define to the full name and version of this package. */
-#define PACKAGE_STRING "opensaml 1.1.1"
+#define PACKAGE_STRING "opensaml 2.0"
 
 /* Define to the one symbol short name of this package. */
-#define PACKAGE_TARNAME "saml"
+#define PACKAGE_TARNAME "opensaml"
 
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "1.1.1"
+#define PACKAGE_VERSION "2.0"
 
 /* Define to the necessary symbol if this constant uses a non-standard name on
    your system. */
@@ -90,10 +83,14 @@
 /* #undef TM_IN_SYS_TIME */
 
 /* Version number of package */
-#define VERSION "1.1.1"
+#define VERSION "2.0"
 
 /* Define to empty if `const' does not conform to ANSI C. */
 /* #undef const */
 
 /* Define to `unsigned' if <sys/types.h> does not define. */
 /* #undef size_t */
+
+/* The size of a `time_t', as computed by sizeof. */
+#define SIZEOF_TIME_T 8
+
